==> zio-aws-personalizeevents_3-5.17.125.1-sources.jar: zio/aws/personalizeevents/model/package.scala <==
package zio.aws.personalizeevents
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.personalizeevents.model.primitives.ItemId
import zio.aws.personalizeevents.model.primitives.UserId.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object Arn extends Subtype[String]
    type Arn = zio.aws.personalizeevents.model.primitives.Arn.Type
    object Date extends Subtype[Instant]
    type Date = zio.aws.personalizeevents.model.primitives.Date.Type
    object EventPropertiesJSON extends Subtype[String]
    type EventPropertiesJSON =
      zio.aws.personalizeevents.model.primitives.EventPropertiesJSON.Type
    object FloatType extends Subtype[Float]
    type FloatType = zio.aws.personalizeevents.model.primitives.FloatType.Type
    object ItemId extends Subtype[String]
    type ItemId = zio.aws.personalizeevents.model.primitives.ItemId.Type
    object ItemProperties extends Subtype[String]
    type ItemProperties =
      zio.aws.personalizeevents.model.primitives.ItemProperties.Type
    object RecommendationId extends Subtype[String]
    type RecommendationId =
      zio.aws.personalizeevents.model.primitives.RecommendationId.Type
    object StringType extends Subtype[String]
    type StringType = zio.aws.personalizeevents.model.primitives.StringType.Type
    object UserId extends Subtype[String]
    type UserId = zio.aws.personalizeevents.model.primitives.UserId.Type
    object UserProperties extends Subtype[String]
    type UserProperties =
      zio.aws.personalizeevents.model.primitives.UserProperties.Type
  }
  type EventList = List[zio.aws.personalizeevents.model.Event]
  type Impression = List[ItemId]
  type ItemList = List[zio.aws.personalizeevents.model.Item]
  type UserList = List[zio.aws.personalizeevents.model.User]
}

==> zio-aws-personalizeevents_3-5.17.147.1-sources.jar: zio/aws/personalizeevents/model/package.scala <==
package zio.aws.personalizeevents
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.personalizeevents.model.primitives.ItemId
import zio.aws.personalizeevents.model.primitives.UserId.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object Arn extends Subtype[String]
    type Arn = zio.aws.personalizeevents.model.primitives.Arn.Type
    object Date extends Subtype[Instant]
    type Date = zio.aws.personalizeevents.model.primitives.Date.Type
    object EventPropertiesJSON extends Subtype[String]
    type EventPropertiesJSON =
      zio.aws.personalizeevents.model.primitives.EventPropertiesJSON.Type
    object FloatType extends Subtype[Float]
    type FloatType = zio.aws.personalizeevents.model.primitives.FloatType.Type
    object ItemId extends Subtype[String]
    type ItemId = zio.aws.personalizeevents.model.primitives.ItemId.Type
    object ItemProperties extends Subtype[String]
    type ItemProperties =
      zio.aws.personalizeevents.model.primitives.ItemProperties.Type
    object RecommendationId extends Subtype[String]
    type RecommendationId =
      zio.aws.personalizeevents.model.primitives.RecommendationId.Type
    type StringType = String
    object UserId extends Subtype[String]
    type UserId = zio.aws.personalizeevents.model.primitives.UserId.Type
    object UserProperties extends Subtype[String]
    type UserProperties =
      zio.aws.personalizeevents.model.primitives.UserProperties.Type
  }
  type EventList = List[zio.aws.personalizeevents.model.Event]
  type Impression = List[ItemId]
  type ItemList = List[zio.aws.personalizeevents.model.Item]
  type UserList = List[zio.aws.personalizeevents.model.User]
}
